starcluster.config

Package starcluster :: Module config |
[hide private]
[frames] | no frames]

# Module config

source code

Classes | [hide private]
| StarClusterConfig Loads StarCluster configuration settings defined in config_file which defaults to ~/.starclustercfg

Functions | [hide private]
get_easy_s3(config_file=None, cache=False) Factory for EasyS3 class that attempts to load AWS credentials from the StarCluster config file. | source code
get_easy_ec2(config_file=None, cache=False) Factory for EasyEC2 class that attempts to load AWS credentials from the StarCluster config file. | source code
get_cluster_manager(config_file=None, cache=False) Factory for ClusterManager class that attempts to load AWS credentials from the StarCluster config file. | source code
get_config(config_file=None, cache=False) Factory for StarClusterConfig object | source code

Variables | [hide private]
| DEBUG_CONFIG = `False`
| __package__ = ``'``starcluster``'``

Function Details | [hide private]

### get_easy_s3(config_file=None, cache=False) | source code
Factory for EasyS3 class that attempts to load AWS credentials from the StarCluster config file. Returns an EasyS3 object if successful.

### get_easy_ec2(config_file=None, cache=False) | source code
Factory for EasyEC2 class that attempts to load AWS credentials from the StarCluster config file. Returns an EasyEC2 object if successful.

### get_cluster_manager(config_file=None, cache=False) | source code
Factory for ClusterManager class that attempts to load AWS credentials from the StarCluster config file. Returns a ClusterManager object if successful